@@ -3,19 +3,20 @@ from json import loads
 from fastapi_helpers.crud import BaseCrud
 from logging import getLogger
 
-class DbSeeder():
 
+class DbSeeder:
     crud = None
 
     def __init__(self, crud_module) -> None:
         self.crud = crud_module
 
     async def read_index(
-        self, 
-        main_path:str="../seeds/", 
-        index_path:str="index.json"
+            self,
+            main_path: str = "../seeds/",
+            index_path: str = "index.json"
     ) -> bool:
         logger = getLogger("fastapi")
+        logger.info("Reading index file", extra={"path": index_path, "main_path": main_path, "crud": self.crud})
         index = open(path.join(main_path, index_path), "r")
         index_content = "".join(index.readlines())
         index.close()
